### Name: population.check
### Title: Compliance test for known totals data frames
### Aliases: population.check
### Keywords: survey

### ** Examples

data(data.examples)

# Suppose you have to calibrate the esempio survey data frame
# on the totals of x1 by sex and you want the iterative solution.
# Start creating a kott.design object:
kdes<-kottdesign(data=example,ids=~towcod+famcod,strata=~SUPERSTRATUM,
      weights=~weight,nrg=15)

# Then build a template data frame for the known totals:
pop<-pop.template(data=example,calmodel=~x1-1,partition=~sex)
pop
class(pop)

# Now fill NAs with the actual values for the population
# totals (suppose 123 for sex="f" and 456 for sex="m"): 
pop[,"x1"]<-c(123,456)
pop
class(pop)

# Finally check if pop complies with the kottcalibrate standard:
population.check(df.population=pop,data=example,calmodel=~x1-1,
                 partition=~sex)

# If, despite keeping the content unchanged, we altered the
# structure of the data frame (for example, by changing the 
# order of its rows)...
pop.mod<-pop ; pop.mod[1,]<-pop[2,] ; pop.mod[2,]<-pop[1,]
pop
pop.mod

# ... we would obtain an error:
## Not run: 
##D population.check(df.population=pop.mod,data=example,calmodel=~x1-1,
##D                           partition=~sex)
## End(Not run)

# Remember that, if the known totals have been converted
# into the pop.totals "format" by means of population.check,
# it is possible to invoke kottcalibrate without specifying
# calmodel and partition: 

class(pop04p)
pop04p
kdescal04p<-kottcalibrate(deskott=kdes,df.population=pop04p,
            calfun="logit",bounds=bounds,aggregate.stage=2)

# ... this option is not allowed if the known totals
# are not of class pop.totals even if they conform to the
# standard:

pop04p.mod=data.frame(pop04p)
class(pop04p.mod)
pop04p.mod
## Not run: 
##D kottcalibrate(deskott=kdes,df.population=pop04p.mod,calfun="logit",
##D               bounds=bounds,aggregate.stage=2)
## End(Not run)



